%define oname YafaRay

%if %{_use_internal_dependency_generator}
%define __noautoprovfiles '%{python_sitearch}/(.*)\.so$|%{_libdir}/yafaray'
%else
%define _exclude_files_from_autoprov ^%{python_sitearch}/.*\.so$\\|%{_libdir}/yafaray
%endif

Summary:	A free open-source raytracing render engine
Name:		yafaray
Version:	0.1.1
Release:	%mkrel 7
License:	LGPLv2.1
Group:		Graphics/3D
URL:		http://www.yafray.org
Source0:	http://static.yafaray.org/sources/%{oname}.%{version}.zip
Source1:	http://static.yafaray.org/sources/%{oname}-blender.%{version}.zip
BuildRequires:	scons
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	jpeg-devel
BuildRequires:	python-devel
BuildRequires:	swig
BuildRequires:	qt4-devel
BuildRequires:	pkgconfig(zlib)
Obsoletes:	yafray < %{version}
Provides:	yafray = %{version}

%description
YafaRay is a free open-source raytracing render engine.

Raytracing is a rendering technique for generating realistic images by
tracing the path of light through a 3D scene. A render engine consists of
a "faceless" computer program that interacts with a host 3D application
to provide very specific raytracing capabilities "on demand". Blender 3D
is the host application of YafaRay.

%package blender
Summary:	Blender integration scripts
Group:		Graphics/3D
Requires:	%{name} = %{version}-%{release}
Requires:	blender

%description blender
YafRay uses a python-coded settings interface to set lighting and rendering
parameters. This settings interface is launched by an entry automatically
added to the Blender Render menu.

%prep
%setup -q -n %{name}
%setup -q -D -T -a 1 -n %{name}

sed -i -e"s,/lib',/%{_lib}',g" config/linux2-config.py
sed -i -e"s,/lib/,/%{_lib}/,g" config/linux2-config.py
sed -i -e"s,WITH_YF_QT='false',WITH_YF_QT='true',g" config/linux2-config.py

cat << EOF >> config/linux2-config.py
YF_QTDIR = '%{_libdir}/qt4'
# unversioned SO is correct by itself when the said shared object is
# meant to be dlopen at runtime, instead of being linked at build time.
#YF_SHLINKFLAGS = "-Wl,-soname,libyafaraycore.so.1"
EOF
sed -i -e"s|REL_CCFLAGS = '-O3 -ffast-math'|REL_CCFLAGS = '-ffast-math -fPIC %{optflags}'|g" config/linux2-config.py
sed -i -e"s|/usr/local|/usr|g" config/linux2-config.py
# fixes %%{buildroot} in libyafaraycore.so
sed -i -e"s,\$YF_LIBOUT,%{_libdir},g" tools/writeconfig.py
sed -i -e"s,\$YF_PLUGINPATH,%{_libdir}/%{name},g" tools/writeconfig.py

%build
scons build
scons swig

%install
scons PREFIX=%{buildroot}%{_prefix} install

mkdir -p %{buildroot}%{_datadir}/blender/scripts
mkdir -p %{buildroot}%{python_sitearch}

cp -p bindings/python/yaf*.py \
      %{buildroot}%{_datadir}/blender/scripts
cp -p bindings/python/_yaf*.so \
      %{buildroot}%{python_sitearch}
cp -p %{name}-blender/yaf*.py \
      %{buildroot}%{_datadir}/blender/scripts

# FIXME workaround for: https://github.com/K-3D/k3d/issues/15
ln -s %{_bindir}/%{name}-xml %{buildroot}%{_bindir}/yafray

%files
%doc CODING
%{_bindir}/yafray
%{_bindir}/%{name}-xml
%{_libdir}/%{name}/*.so
%{_libdir}/libyafaraycore.so

%files blender
%{_datadir}/blender/scripts/*
%{_libdir}/libyafarayqt.so
%{_libdir}/libyafarayplugin.so
%{python_sitearch}/_yaf*.so


%changelog
* Sat Feb 06 2016 umeabot <umeabot> 0.1.1-7.mga6
+ Revision: 941820
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.1.1-6.mga5
+ Revision: 748613
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 alexl <alexl> 0.1.1-5.mga5
+ Revision: 731445
- added symlink /usr/bin/yafray

* Tue Sep 16 2014 umeabot <umeabot> 0.1.1-4.mga5
+ Revision: 690815
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 luigiwalser <luigiwalser> 0.1.1-3.mga5
+ Revision: 667002
- rebuild for ilmbase and OpenEXR

* Thu May 01 2014 luigiwalser <luigiwalser> 0.1.1-2.mga5
+ Revision: 619157
- rebuild for ilmbase

* Wed Apr 16 2014 alexl <alexl> 0.1.1-1.mga5
+ Revision: 615318
- version 0.1.1 with blender integration
- rename yafray in yafaray
- rename yafray in yafaray

* Tue Apr 15 2014 alexl <alexl> 0.0.9-1.mga5
+ Revision: 615152
- imported package yafray

